# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.compliance_status_detail import ComplianceStatusDetail

class TestComplianceStatusDetail(unittest.TestCase):
    """ComplianceStatusDetail unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ComplianceStatusDetail:
        """Test ComplianceStatusDetail
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ComplianceStatusDetail`
        """
        model = ComplianceStatusDetail()
        if include_optional:
            return ComplianceStatusDetail(
                status = 'PENDING',
                alert_rules = arthur_client.api_bindings.models.compliance_alert_rule_results.ComplianceAlertRuleResults(
                    compliant = [
                        arthur_client.api_bindings.models.compliant_alert_rule_status.CompliantAlertRuleStatus(
                            id = '', 
                            name = '', )
                        ], 
                    non_compliant = [
                        arthur_client.api_bindings.models.non_compliant_alert_rule_status.NonCompliantAlertRuleStatus(
                            id = '', 
                            name = '', 
                            alert = arthur_client.api_bindings.models.compliance_alert_summary.ComplianceAlertSummary(
                                description = '', 
                                id = '', ), )
                        ], ),
                attestation_rules = arthur_client.api_bindings.models.compliance_attestation_rule_results.ComplianceAttestationRuleResults(
                    compliant = [
                        arthur_client.api_bindings.models.compliant_attestation_rule_status.CompliantAttestationRuleStatus(
                            id = '', 
                            name = '', 
                            notes = '', 
                            expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                        ], 
                    non_compliant = [
                        arthur_client.api_bindings.models.non_compliant_attestation_rule_status.NonCompliantAttestationRuleStatus(
                            id = '', 
                            name = '', )
                        ], )
            )
        else:
            return ComplianceStatusDetail(
                status = 'PENDING',
                alert_rules = arthur_client.api_bindings.models.compliance_alert_rule_results.ComplianceAlertRuleResults(
                    compliant = [
                        arthur_client.api_bindings.models.compliant_alert_rule_status.CompliantAlertRuleStatus(
                            id = '', 
                            name = '', )
                        ], 
                    non_compliant = [
                        arthur_client.api_bindings.models.non_compliant_alert_rule_status.NonCompliantAlertRuleStatus(
                            id = '', 
                            name = '', 
                            alert = arthur_client.api_bindings.models.compliance_alert_summary.ComplianceAlertSummary(
                                description = '', 
                                id = '', ), )
                        ], ),
                attestation_rules = arthur_client.api_bindings.models.compliance_attestation_rule_results.ComplianceAttestationRuleResults(
                    compliant = [
                        arthur_client.api_bindings.models.compliant_attestation_rule_status.CompliantAttestationRuleStatus(
                            id = '', 
                            name = '', 
                            notes = '', 
                            expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                        ], 
                    non_compliant = [
                        arthur_client.api_bindings.models.non_compliant_attestation_rule_status.NonCompliantAttestationRuleStatus(
                            id = '', 
                            name = '', )
                        ], ),
        )
        """

    def testComplianceStatusDetail(self):
        """Test ComplianceStatusDetail"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
