# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.set_compliance_status_request import SetComplianceStatusRequest

class TestSetComplianceStatusRequest(unittest.TestCase):
    """SetComplianceStatusRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SetComplianceStatusRequest:
        """Test SetComplianceStatusRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SetComplianceStatusRequest`
        """
        model = SetComplianceStatusRequest()
        if include_optional:
            return SetComplianceStatusRequest(
                compliance_status = arthur_client.api_bindings.models.compliance_status_detail.ComplianceStatusDetail(
                    status = 'PENDING', 
                    alert_rules = arthur_client.api_bindings.models.compliance_alert_rule_results.ComplianceAlertRuleResults(
                        compliant = [
                            arthur_client.api_bindings.models.compliant_alert_rule_status.CompliantAlertRuleStatus(
                                id = '', 
                                name = '', )
                            ], 
                        non_compliant = [
                            arthur_client.api_bindings.models.non_compliant_alert_rule_status.NonCompliantAlertRuleStatus(
                                id = '', 
                                name = '', 
                                alert = arthur_client.api_bindings.models.compliance_alert_summary.ComplianceAlertSummary(
                                    description = '', 
                                    id = '', ), )
                            ], ), 
                    attestation_rules = arthur_client.api_bindings.models.compliance_attestation_rule_results.ComplianceAttestationRuleResults(), )
            )
        else:
            return SetComplianceStatusRequest(
                compliance_status = arthur_client.api_bindings.models.compliance_status_detail.ComplianceStatusDetail(
                    status = 'PENDING', 
                    alert_rules = arthur_client.api_bindings.models.compliance_alert_rule_results.ComplianceAlertRuleResults(
                        compliant = [
                            arthur_client.api_bindings.models.compliant_alert_rule_status.CompliantAlertRuleStatus(
                                id = '', 
                                name = '', )
                            ], 
                        non_compliant = [
                            arthur_client.api_bindings.models.non_compliant_alert_rule_status.NonCompliantAlertRuleStatus(
                                id = '', 
                                name = '', 
                                alert = arthur_client.api_bindings.models.compliance_alert_summary.ComplianceAlertSummary(
                                    description = '', 
                                    id = '', ), )
                            ], ), 
                    attestation_rules = arthur_client.api_bindings.models.compliance_attestation_rule_results.ComplianceAttestationRuleResults(), ),
        )
        """

    def testSetComplianceStatusRequest(self):
        """Test SetComplianceStatusRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
